@@ -22,7 +22,7 @@ CSRF_COOKIE_SECURE = False
 SESSION_COOKIE_SAMESITE = "Lax"
 
 # CMS authentication
-IDA_LOGOUT_URI_LIST.append("http://{{ CMS_HOST }}:8001/complete/logout")
+IDA_LOGOUT_URI_LIST.append("http://{{ CMS_HOST }}:8001/logout/")
 
 FEATURES['ENABLE_COURSEWARE_MICROFRONTEND'] = False
 
